@@ -2,11 +2,13 @@
 # Copyright (C) 2009 NZ Registry Services
 ## ----------------------------------------------------------------------------
 package XML::Compare;
+$XML::Compare::VERSION = '0.05';
+use 5.006;
+use Moo 2;
+use MooX::Types::MooseLike::Base qw(Bool Str ArrayRef HashRef Undef);
 
-use XML::LibXML;
-use Any::Moose;
+use XML::LibXML 1.58;
 
-our $VERSION = '0.04';
 our $VERBOSE = $ENV{XML_COMPARE_VERBOSE} || 0;
 
 my $PARSER = XML::LibXML->new();
@@ -41,13 +43,13 @@ my $has = {
 
 has 'namespace_strict' =>
     is => "rw",
-    isa => "Bool",
+    isa => Bool,
     default => 0,
     ;
 
 has 'error' =>
     is => "rw",
-    isa => "Str",
+    isa => Str,
     clearer => "_clear_error",
     ;
 
@@ -91,7 +93,7 @@ sub is_different {
 # private functions
 sub _xpath {
     my $l = shift;
-    "/".join("/",@$l);
+    return "/".join("/",@$l);
 }
 
 sub _die {
@@ -158,17 +160,17 @@ sub _are_docs_same {
 
 has 'ignore' =>
     is => "rw",
-    isa => "ArrayRef[Str]",
+    isa => ArrayRef[Str],
     ;
 
 has 'ignore_xmlns' =>
     is => "rw",
-    isa => "HashRef[Str]",
+    isa => HashRef[Str],
     ;
 
 has '_ignore_nodes' =>
     is => "rw",
-    isa => "HashRef[Undef]",
+    isa => HashRef[Undef],
     clearer => "_ignore_nothing",
     ;
 
@@ -243,7 +245,7 @@ sub _are_nodes_same {
                 _die $l, 'namespaceURIs are different: (%s, %s)', $ns1, $ns2;
             }
         }
-        elsif ( !defined $ns1 and !defined $ns2 ) {
+        elsif ( (!defined $ns1) and (!defined $ns2) ) {
             _same($l, 'namespaceURI (not defined for either node)');
         }
         else {
@@ -260,12 +262,12 @@ sub _are_nodes_same {
 	my $in = $self->_ignore_nodes;
         # get just the Attrs and sort them by namespaceURI:localname
         my @attr1 = sort { _fullname($a) cmp _fullname($b) }
-	    grep { !$in or !exists $in->{$_->nodePath} }
+	    grep { (!$in) or (!exists $in->{$_->nodePath}) }
 		grep { defined and $_->isa('XML::LibXML::Attr') }
 		    $node1->attributes();
 
         my @attr2 = sort { _fullname($a) cmp _fullname($b) }
-	    grep { !$in or !exists $in->{$_->nodePath} }
+	    grep { (!$in) or (!exists $in->{$_->nodePath}) }
 		grep { defined and $_->isa('XML::LibXML::Attr') }
 		    $node2->attributes();
 
@@ -287,15 +289,15 @@ sub _are_nodes_same {
     my $in = $self->_ignore_nodes;
 
     # don't need to compare or care about Comments
-    my @nodes1 = grep { !$in or !exists $in->{$_->nodePath} }
-	grep { ! $_->isa('XML::LibXML::Comment') and
-		   !($_->isa("XML::LibXML::Text") && ($_->data =~ /\A\s*\Z/))
+    my @nodes1 = grep { (!$in) or (!exists $in->{$_->nodePath}) }
+	grep { (not $_->isa('XML::LibXML::Comment')) and
+		   not ( $_->isa("XML::LibXML::Text") && ($_->data =~ /\A\s*\Z/) )
 	       }
 	    $node1->childNodes();
 
-    my @nodes2 = grep { !$in or !exists $in->{$_->nodePath} }
-	grep { ! $_->isa('XML::LibXML::Comment') and
-		   !($_->isa("XML::LibXML::Text") && ($_->data =~ /\A\s*\Z/))
+    my @nodes2 = grep { (!$in) or (!exists $in->{$_->nodePath}) }
+	grep { (not $_->isa('XML::LibXML::Comment')) and
+		   not ( $_->isa("XML::LibXML::Text") && ($_->data =~ /\A\s*\Z/) )
 	       } $node2->childNodes();
 
     # firstly, convert all CData nodes to Text Nodes
@@ -315,7 +317,6 @@ sub _are_nodes_same {
     my $total_nodes = scalar @nodes1;
     for (my $i = 0; $i < $total_nodes; $i++ ) {
         # recurse down (either an exception will be thrown, or all are correct
-	my $xpath_nodeName;
 	my $nn = $nodes1[$i]->nodeName;
 	if ( grep { $_->nodeName eq $nn }
 		 @nodes1[0..$i-1, $i+1..$#nodes1] ) {
@@ -491,9 +492,14 @@ Nothing.
 
 L<XML::LibXML>
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/XML-Compare>
+
 =head1 AUTHOR
 
-Andrew Chilton, E<lt>andychilton@gmail.com<gt>, E<lt>andy@catalyst dot net dot nz<gt>
+Andrew Chilton, E<lt>andychilton@gmail.comE<gt>,
+E<lt>andy@catalyst dot net dot nz<gt>
 
 http://www.chilts.org/blog/
 
